@@ -91,9 +91,9 @@ int main (){ return 0; }
 #define FIRST_PROCESS 1
 #endif
 #define MAX_PROCESSES 999999 
-#if defined (__x86_64) > 0 
+#if (defined (__x86_64) > 0  || defined (__amd64) > 0) 
 #undef MAX_PROCESSES
-#define MAX_PROCESSES 4194384
+#define MAX_PROCESSES 4194304
 #endif
 #define MAX_BUF 1024
 
